<?php

namespace Drupal\geofield_map\Services;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Language\LanguageManagerInterface;

/**
 * Class GoogleMapsService.
 */
class GoogleMapsService {

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $config;

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * The Gmap Api Key.
   *
   * @var string
   */
  protected $gmapApiKey;

  /**
   * The Gmap Api Key.
   *
   * @var array
   */
  public $gmapApiLocalization = [
    'default' => '//maps.googleapis.com/maps/api/js',
    'china' => '//maps.google.cn/maps/api/js',
  ];

  /**
   * Set the module related Gmap API Key.
   *
   * @return string
   *   The GmapApiKey
   */
  protected function setGmapApiKey() {
    return $this->config->get('geofield_map.settings')->get('gmap_api_key');
  }

  /**
   * Constructs a new GoogleMapsService object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   A config factory for retrieving required config objects.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    LanguageManagerInterface $language_manager
  ) {
    $this->config = $config_factory;
    $this->languageManager = $language_manager;
    $this->gmapApiKey = $this->setGmapApiKey();

  }

  /**
   * Get the module related Gmap API Key.
   *
   * @return string
   *   The GmapApiKey
   */
  public function getGmapApiKey() {
    return $this->gmapApiKey;
  }

  /**
   * Get the localized Gmap API Library.
   *
   * @param string $index
   *   The index parameter.
   *
   * @return string
   *   The Gmap Api library base Url
   */
  public function getGmapApiLocalization($index = 'default') {
    return isset($this->gmapApiLocalization[$index]) ? $this->gmapApiLocalization[$index] : $this->gmapApiLocalization['default'];
  }

}
